/* Colors for the standard dir browser table */

/* Alternate colours for the directory list table */
#entrylist tr:nth-child(even) {
    background-color: #dddddd;
}
#entrylist td:empty {
    background-color: white;
}
#entrylist tr:nth-child(odd) {
    background-color: white;
}
div#fixedheader {
    background-color: white;
}
div#browsepath {
    background-color: white;
}

td.aheadimg {
    padding-right: 10px;
}

.albumheader {
    background-color: #dddddd;
}
